@@ -46,14 +46,58 @@
 #endif
 
 #include "llvm-c/Transforms/PassManagerBuilder.h"
-
-
 #include "llvm_c_extra.h"
 
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+
+#if LLVM_VERSION_MAJOR >= 3 && LLVM_VERSION_MINOR >= 2
+/*
+ * Wraps new TargetTransformInfo(
+ *          TargetMachine::getScalarTargetTransformInfo,
+ *          TargetMachine::getVectorTargetTransformInfo)
+ */
+LLVMPassRef LLVMCreateTargetTransformInfo(LLVMTargetMachineRef tmref);
+#endif 
+
+/*
+ * Wraps new TargetLibraryInfo
+ */
+LLVMPassRef LLVMCreateTargetLibraryInfo(const char * triple);
+
+/*
+ * Wraps llvm::getDefaultTargetTriple
+ */
+const char * LLVMDefaultTargetTriple();
+
+/*
+ * Wraps Pass::lookupPassInfo and PassInfo::createPass
+ */
+LLVMPassRef LLVMCreatePassByName(const char *name);
+
+/*
+ * Wraps operator delete (Pass*)
+ */
+void LLVMDisposePass(LLVMPassRef passref);
+
+/*
+ * Wraps Pass::getPassName
+ */
+const char * LLVMGetPassName(LLVMPassRef passref);
+
+/*
+ * Wraps PassManager::add
+ */
+void LLVMAddPass(LLVMPassManagerRef pmref, LLVMPassRef passref);
+
+/*
+ * Wraps Pass::dump
+ */
+void LLVMPassDump(LLVMPassRef passref);
+
 /*
  * Wraps llvm:InlineAsm::get
  */
@@ -154,6 +198,11 @@ int LLVMInitializeNativeTargetAsmPrinter();
 
 LLVMTargetMachineRef LLVMTargetMachineLookup(const char *arch, const char *cpu,
                                              const char *features, int opt,
+                                             int codemodel, std::string &error);
+
+LLVMTargetMachineRef LLVMCreateTargetMachine(const char *arch, const char *cpu,
+                                             const char *features, int opt,
+                                             int codemodel,
                                              std::string &error);
 
 /*
@@ -292,6 +341,14 @@ void LLVMEngineBuilderSetMAttrs(LLVMEngineBuilderRef eb, const char * mattrs);
 LLVMExecutionEngineRef LLVMEngineBuilderCreate(LLVMEngineBuilderRef eb,
                                                std::string &error);
 
+/*
+ * Wraps EngineBuilder::create(TargetMachine*)
+ */
+LLVMExecutionEngineRef LLVMEngineBuilderCreateTM(LLVMEngineBuilderRef ebref,
+                                                 LLVMTargetMachineRef tmref,
+                                                 std::string & error);
+
+
 /*
  * Wraps PassManagerBuilder::OptLevel
  */
@@ -312,6 +369,19 @@ void LLVMPassManagerBuilderSetVectorize(LLVMPassManagerBuilderRef pmb, int flag)
  */
 int LLVMPassManagerBuilderGetVectorize(LLVMPassManagerBuilderRef pmb);
 
+#if LLVM_VERSION_MAJOR >= 3 && LLVM_VERSION_MINOR >= 2
+/*
+ * Wraps PassManagerBuilder::LoopVectorize
+ */
+void LLVMPassManagerBuilderSetLoopVectorize(LLVMPassManagerBuilderRef pmb,
+                                            int flag);
+
+/*
+ * Wraps PassManagerBuilder::LoopVectorize
+ */
+int LLVMPassManagerBuilderGetLoopVectorize(LLVMPassManagerBuilderRef pmb);
+#endif // llvm-3.2
+
 /*
  * Wraps PassManagerBuilder::DisableUnitAtATime
  */
@@ -507,8 +577,8 @@ LLVMModuleRef LLVMGetModuleFromBitcode(const char *bc, unsigned bclen,
 /* Wraps llvm::Linker::LinkModules().  Returns 0 on failure (with errmsg
  * filled in) and 1 on success.  Dispose error message after use with
  * LLVMDisposeMessage(). */
-unsigned LLVMLinkModules(LLVMModuleRef dest, LLVMModuleRef src,
-			 unsigned int, char **errmsg);
+unsigned LLVMLinkModules(LLVMModuleRef dest, LLVMModuleRef src, int mode,
+                         char **errmsg);
 #endif
 /* Returns pointer to a heap-allocated block of `*len' bytes containing bit code
  * for the given module. NULL on error. */
@@ -519,6 +589,11 @@ unsigned char *LLVMGetBitcodeFromModule(LLVMModuleRef module, size_t *len);
  * use, via LLVMDisposeMessage(). */
 unsigned LLVMLoadLibraryPermanently(const char* filename, char **errmsg);
 
+/* Wraps llvm::ExecutionEngine::DisableLazyCompilation(bool)
+ */
+void LLVMExecutionEngineDisableLazyCompilation(LLVMExecutionEngineRef ee,
+                                               int flag);
+
 /* Wraps llvm::ExecutionEngine::getPointerToFunction(). Returns a pointer
  * to the JITted function. */
 void *LLVMGetPointerToFunction(LLVMExecutionEngineRef ee, LLVMValueRef fn);
