@@ -494,6 +494,7 @@ class CBuilder(object):
                 # new constant string
                 globalstr = mod.add_global_variable(content.type, name=name)
                 globalstr.initializer = content
+                globalstr.linkage = lc.LINKAGE_LINKONCE_ODR
                 globalstr.global_constant = True
             else:
                 # compare existing content
@@ -784,7 +785,7 @@ class CDefinition(object):
         cls._name_ = "%s_%d" % (cls._name_, counter)
         cls.counter = counter + 1
 
-    def define(self, module):
+    def define(self, module, optimize=True):
         '''define the function in the module.
 
         Raises NameError if a function of the same name has already been
@@ -814,13 +815,13 @@ class CDefinition(object):
         self.cbuilder.close()
         self.cbuilder = None
 
-        # optimize
-        fpm = lp.FunctionPassManager.new(module)
-        pmb = lp.PassManagerBuilder.new()
-        pmb.opt_level = 3
-        pmb.vectorize = True
-        pmb.populate(fpm)
-        fpm.run(func)
+        if optimize:
+            fpm = lp.FunctionPassManager.new(module)
+            pmb = lp.PassManagerBuilder.new()
+            pmb.opt_level = 2
+            pmb.populate(fpm)
+            fpm.run(func)
+
         return func
 
     def __call__(self, module):
@@ -1133,11 +1134,11 @@ class PointerIndexing(OperatorMixin):
             # Case #1: A[idx:] get pointer offset by idx
             if not idx.step and not idx.stop:
                 idx = _auto_coerce_index(self.parent, idx.start)
-                ptr = bldr.gep(self.value, [idx.value])
+                ptr = bldr.gep(self.value, [idx.value], inbounds=True)
                 return CArray(self.parent, ptr)
         else: # return an variable at idx
             idx = _auto_coerce_index(self.parent, idx)
-            ptr = bldr.gep(self.value, [idx.value])
+            ptr = bldr.gep(self.value, [idx.value], inbounds=True)
             return CVar(self.parent, ptr)
 
     def __setitem__(self, idx, val):
@@ -1182,7 +1183,7 @@ class PointerValue(PointerIndexing, PointerCasting):
         inst = self.parent.builder.store(val.value, self.value, **kws)
         if nontemporal:
             self.parent.set_memop_non_temporal(inst)
-
+        return inst
 
     def atomic_load(self, ordering, align=None, crossthread=True):
         '''atomic load memory for pointer types
