@@ -2,13 +2,14 @@ from llvm.core import *
 from llvm.passes import *
 from llvm.ee import *
 import llvm
+from llvm.test_llvmpy import TestCase
 from os.path import dirname, join as join_path
 
 
 import unittest
 import re
 
-class TestLoopVectorizer(unittest.TestCase):
+class TestLoopVectorizer(TestCase):
     def test_loop_vectorizer(self):
         if llvm.version <= (3, 1):
             return # SKIP
